@@ -1,4 +1,4 @@
-'''
+"""
 Version3 API
 ============
 
@@ -15,20 +15,30 @@ Methods available on ``tio.v3``:
     :glob:
 
     explore/index
-'''
+    access_control
+"""
 from tenable.base.endpoint import APIEndpoint
+from tenable.io.v3.access_control import AccessControlAPI
 from tenable.io.v3.explore import Explore
 
 
 class Version3API(APIEndpoint):
-    '''
+    """
     This will contain property for all resources/app under Tenable.io - V3.
-    '''
+    """
 
     @property
     def explore(self):
-        '''
+        """
         The interface object for the
          :doc:`Tenable.io v3 explore <explore/index>`
-        '''
+        """
         return Explore(self._api)
+
+    @property
+    def access_control(self):
+        """
+        The interface object for the
+         :doc:`Tenable.io v3 access control <access_control>`
+        """
+        return AccessControlAPI(self._api)
